@@ -1,6 +1,7 @@
 <?php
+
 /**
- * @file views-view-grid.tpl.php
+ * @file
  * Default simple view template to display a rows in a grid.
  *
  * - $rows contains a nested array of rows. Each row contains an array of
@@ -13,11 +14,15 @@
   <h3><?php print $title; ?></h3>
 <?php endif; ?>
 <table class="<?php print $class; ?>"<?php print $attributes; ?>>
+  <?php if (!empty($caption)) : ?>
+    <caption><?php print $caption; ?></caption>
+  <?php endif; ?>
+
   <tbody>
     <?php foreach ($rows as $row_number => $columns): ?>
-      <tr class="<?php print $row_classes[$row_number]; ?>">
+      <tr <?php if ($row_classes[$row_number]) { print 'class="' . $row_classes[$row_number] .'"';  } ?>>
         <?php foreach ($columns as $column_number => $item): ?>
-          <td class="<?php print $column_classes[$row_number][$column_number]; ?>">
+          <td <?php if ($column_classes[$row_number][$column_number]) { print 'class="' . $column_classes[$row_number][$column_number] .'"';  } ?>>
             <?php print $item; ?>
           </td>
         <?php endforeach; ?>
